summaryrefslogtreecommitdiffstats
path: root/smb4k/searchdlg/smb4ksearchdialog_part.h
diff options
context:
space:
mode:
Diffstat (limited to 'smb4k/searchdlg/smb4ksearchdialog_part.h')
-rw-r--r--smb4k/searchdlg/smb4ksearchdialog_part.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/smb4k/searchdlg/smb4ksearchdialog_part.h b/smb4k/searchdlg/smb4ksearchdialog_part.h
index 633b217..4ff69dd 100644
--- a/smb4k/searchdlg/smb4ksearchdialog_part.h
+++ b/smb4k/searchdlg/smb4ksearchdialog_part.h
@@ -58,16 +58,16 @@ class Smb4KSearchDialogPart : public KParts::Part
/**
* The constructor.
*
- * @param parentWidget The tqparent widget
+ * @param parentWidget The parent widget
*
* @param widgetName The name the widget should have
*
* @param tqparent The tqparent object
*
* @param name The name this object should have
*/
Smb4KSearchDialogPart( TQWidget *parentWidget = 0, const char *widgetName = 0,
- TQObject *tqparent = 0, const char *name = 0 );
+ TQObject *parent = 0, const char *name = 0 );
/**
* The destructor.
@@ -150,7 +150,7 @@ class Smb4KSearchDialogPartFactory : public KParts::Factory
* Reimplemented from KParts::Factory
*/
virtual KParts::Part *createPartObject( TQWidget *parentWidget, const char *widgetName,
- TQObject *tqparent, const char *name,
+ TQObject *parent, const char *name,
const char *classname, const TQStringList &args );
/**
@@ -58,16 +58,16 @@ class Smb4KSearchDialogPart : public KParts::Part
* @param widgetName The name the widget should have
*
- * @param tqparent The tqparent object
+ * @param parent The parent object
*
* @param name The name this object should have